@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-template
 version: 2.1.6
-id: persistent-template-2.1.6-42489148129b2fa03f15ca76243f3923
-key: persi_A0LcLyTnfWfHjRP2SYIOdL
+id: persistent-template-2.1.6-6446adcdac00e4cf9aeae54844fe611d
+key: persi_400XbQIHiU7LgM0kmU56l3
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -20,19 +20,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.6
-hs-libraries: HSpersistent-template-2.1.6-A0LcLyTnfWfHjRP2SYIOdL
+hs-libraries: HSpersistent-template-2.1.6-400XbQIHiU7LgM0kmU56l3
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    aeson-compat-0.3.2.0-725b78f3168d9bafe282f8360603746a
+    aeson-compat-0.3.2.0-1377f830a9c306c394b4385c9d316f98
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    monad-logger-0.3.18-d371de410ef611b2a9194c84cfcdfbf6
     path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
-    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
+    persistent-2.2.4.1-840a8f388c4f74e927e97d9dd2d8494d
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
